@@ -13,7 +13,7 @@ from .modules.module_base import ModuleBase
 @pytest.mark.usefixtures('client_cls')
 class CalibrationClientTest(ModuleBase, unittest.TestCase):
     def setUp(self):
-        self.existing_db_05 = {
+        self.exist_db_05 = {
             'id': -5,
             'name': 'CALIBRATION_CONSTANT_VERSION_TEST-5_DO_NOT_DELETE',
             'begin_at': '2016-05-24T12:00:00.000+02:00',
@@ -31,7 +31,7 @@ class CalibrationClientTest(ModuleBase, unittest.TestCase):
             'end_idx': None,
             'description': 'Created automatically via seed:seed_tests'}
 
-        self.existing_db_06 = {
+        self.exist_db_06 = {
             'id': -6,
             'name': 'CALIBRATION_CONSTANT_VERSION_TEST-6_DO_NOT_DELETE',
 
@@ -80,7 +80,7 @@ class CalibrationClientTest(ModuleBase, unittest.TestCase):
         logging.error('resp: {0}'.format(resp))
 
         assert resp['app_info'] == {}
-        assert resp['success'] == True
+        assert resp['success'] is True
 
         success_info_msg = 'calibration_constant_version created successfully'
         assert resp['info'] == success_info_msg
@@ -88,13 +88,13 @@ class CalibrationClientTest(ModuleBase, unittest.TestCase):
         # Calibration Constant Version info
         resp_ccv = resp['data']
         assert resp_ccv['name'] == ccv_h['name']
-        assert resp_ccv['flg_good_quality'] == True
+        assert resp_ccv['flg_good_quality'] is True
 
         assert resp_ccv['begin_validity_at'] == begin_val_at_exp
         assert resp_ccv['end_validity_at'] == end_val_at_exp
         assert resp_ccv['begin_at'] == begin_at_exp
 
-        assert resp_ccv['flg_deployed'] == True
+        assert resp_ccv['flg_deployed'] is True
         assert resp_ccv['raw_data_location'] == ccv_h['raw_data_location']
         assert resp_ccv['file_name'] == ccv_h['file_name']
         assert resp_ccv['path_to_file'] == ccv_h['path_to_file']
@@ -107,8 +107,8 @@ class CalibrationClientTest(ModuleBase, unittest.TestCase):
         # Calibration Constant info
         resp_cc = resp['data']['calibration_constant']
         assert resp_cc['name'] == cc_h['name']
-        assert resp_cc['flg_available'] == True
-        assert resp_cc['flg_auto_approve'] == True
+        assert resp_cc['flg_available'] is True
+        assert resp_cc['flg_auto_approve'] is True
         assert resp_cc['detector_type_id'] == -1
         # assert resp_cc['condition_id'] == -1
         assert resp_cc['calibration_id'] == -1
@@ -118,7 +118,7 @@ class CalibrationClientTest(ModuleBase, unittest.TestCase):
         resp_pd = resp['data']['physical_detector_unit']
         assert resp_pd['id'] == -2
         assert resp_pd['physical_name'] == ccv_h['pdu_physical_name']
-        assert resp_pd['flg_available'] == True
+        assert resp_pd['flg_available'] is True
 
     def test_retrieve_calibration_constant_version(self):
         calibration_hash_01 = CalibrationTestHash(
@@ -157,7 +157,7 @@ class CalibrationClientTest(ModuleBase, unittest.TestCase):
         logging.error('retrieve_h: {0}'.format(retrieve_h))
         logging.error('resp: {0}'.format(resp))
 
-        assert resp['success'] == True
+        assert resp['success'] is True
         assert resp['app_info'] == {}
 
         success_info_msg = 'Got calibration_constant_version successfully'
@@ -166,10 +166,7 @@ class CalibrationClientTest(ModuleBase, unittest.TestCase):
         # Calibration Constant Version info
         resp_ccv = resp['data']
 
-        # print('$' * 200)
-        # print(str(resp_ccv))
-        # print('$' * 200)
-        expected_return = {
+        expected_ret = {
             'id': -6,
             'name': 'CALIBRATION_CONSTANT_VERSION_TEST-6_DO_NOT_DELETE',
             'file_name': 'cal.r0001.c0002.h5',
@@ -199,32 +196,32 @@ class CalibrationClientTest(ModuleBase, unittest.TestCase):
                 'flg_available': True,
                 'description': 'Created automatically via seed:seed_tests'}}
 
-        assert resp_ccv['name'] == expected_return['name']
-        assert resp_ccv['flg_good_quality'] == True
+        assert resp_ccv['name'] == expected_ret['name']
+        assert resp_ccv['flg_good_quality'] is True
 
-        assert resp_ccv['begin_validity_at'] == expected_return[
+        assert resp_ccv['begin_validity_at'] == expected_ret[
             'begin_validity_at']
-        assert resp_ccv['end_validity_at'] == expected_return['end_validity_at']
-        assert resp_ccv['begin_at'] == expected_return['begin_at']
+        assert resp_ccv['end_validity_at'] == expected_ret['end_validity_at']
+        assert resp_ccv['begin_at'] == expected_ret['begin_at']
 
-        assert resp_ccv['flg_deployed'] == True
-        assert resp_ccv['raw_data_location'] == expected_return[
+        assert resp_ccv['flg_deployed'] is True
+        assert resp_ccv['raw_data_location'] == expected_ret[
             'raw_data_location']
-        assert resp_ccv['file_name'] == expected_return['file_name']
-        assert resp_ccv['path_to_file'] == expected_return['path_to_file']
-        assert resp_ccv['description'] == expected_return['description']
+        assert resp_ccv['file_name'] == expected_ret['file_name']
+        assert resp_ccv['path_to_file'] == expected_ret['path_to_file']
+        assert resp_ccv['description'] == expected_ret['description']
         # Special cases...
-        assert resp_ccv['data_set_name'] == expected_return['data_set_name']
-        assert resp_ccv['start_idx'] == expected_return['start_idx']
-        assert resp_ccv['end_idx'] == expected_return['end_idx']
+        assert resp_ccv['data_set_name'] == expected_ret['data_set_name']
+        assert resp_ccv['start_idx'] == expected_ret['start_idx']
+        assert resp_ccv['end_idx'] == expected_ret['end_idx']
 
         # Calibration Constant info
         resp_cc = resp['data']['calibration_constant']
-        expected_return_cc = expected_return['calibration_constant']
+        expected_return_cc = expected_ret['calibration_constant']
 
         assert resp_cc['name'] == expected_return_cc['name']
-        assert resp_cc['flg_available'] == True
-        assert resp_cc['flg_auto_approve'] == True
+        assert resp_cc['flg_available'] is True
+        assert resp_cc['flg_auto_approve'] is True
         assert resp_cc['detector_type_id'] == -1
         # assert resp_cc['condition_id'] == -1
         assert resp_cc['calibration_id'] == -2
@@ -232,11 +229,11 @@ class CalibrationClientTest(ModuleBase, unittest.TestCase):
 
         # Physical Device info
         resp_pd = resp['data']['physical_detector_unit']
-        expected_return_pd = expected_return['physical_detector_unit']
+        expected_return_pd = expected_ret['physical_detector_unit']
 
         assert resp_pd['id'] == -1
         assert resp_pd['physical_name'] == expected_return_pd['physical_name']
-        assert resp_pd['flg_available'] == True
+        assert resp_pd['flg_available'] is True
 
     def test_retrieve_all_calibration_constant_versions(self):
         calibration_hash_01 = CalibrationTestHash(None).valid_search_01
@@ -274,7 +271,7 @@ class CalibrationClientTest(ModuleBase, unittest.TestCase):
         logging.error('retrieve_h: {0}'.format(retrieve_h))
         logging.error('resp: {0}'.format(resp))
 
-        assert resp['success'] == True
+        assert resp['success'] is True
         assert resp['app_info'] == {}
 
         success_info_msg = 'Got calibration_constant_version successfully'
@@ -293,69 +290,69 @@ class CalibrationClientTest(ModuleBase, unittest.TestCase):
         # Calibration Constant Version info (position 0)
         resp_ccv_0 = response_data[0]
 
-        assert resp_ccv_0['name'] == self.existing_db_06['name']
-        assert resp_ccv_0['flg_good_quality'] == self.existing_db_06[
+        assert resp_ccv_0['name'] == self.exist_db_06['name']
+        assert resp_ccv_0['flg_good_quality'] == self.exist_db_06[
             'flg_good_quality']
 
-        assert resp_ccv_0['begin_validity_at'] == self.existing_db_06[
+        assert resp_ccv_0['begin_validity_at'] == self.exist_db_06[
             'begin_validity_at']
-        assert resp_ccv_0['end_validity_at'] == self.existing_db_06[
+        assert resp_ccv_0['end_validity_at'] == self.exist_db_06[
             'end_validity_at']
-        assert resp_ccv_0['begin_at'] == self.existing_db_06['begin_at']
+        assert resp_ccv_0['begin_at'] == self.exist_db_06['begin_at']
 
-        assert resp_ccv_0['flg_deployed'] == self.existing_db_06['flg_deployed']
-        assert resp_ccv_0['raw_data_location'] == self.existing_db_06[
+        assert resp_ccv_0['flg_deployed'] == self.exist_db_06['flg_deployed']
+        assert resp_ccv_0['raw_data_location'] == self.exist_db_06[
             'raw_data_location']
-        assert resp_ccv_0['file_name'] == self.existing_db_06['file_name']
-        assert resp_ccv_0['path_to_file'] == self.existing_db_06['path_to_file']
-        assert resp_ccv_0['description'] == self.existing_db_06['description']
+        assert resp_ccv_0['file_name'] == self.exist_db_06['file_name']
+        assert resp_ccv_0['path_to_file'] == self.exist_db_06['path_to_file']
+        assert resp_ccv_0['description'] == self.exist_db_06['description']
         # Special cases...
-        assert resp_ccv_0['data_set_name'] == self.existing_db_06[
+        assert resp_ccv_0['data_set_name'] == self.exist_db_06[
             'data_set_name']
-        assert resp_ccv_0['start_idx'] == self.existing_db_06['start_idx']
-        assert resp_ccv_0['end_idx'] == self.existing_db_06['end_idx']
+        assert resp_ccv_0['start_idx'] == self.exist_db_06['start_idx']
+        assert resp_ccv_0['end_idx'] == self.exist_db_06['end_idx']
 
         # Calibration Constant info
-        assert resp_ccv_0['calibration_constant']['id'] == self.existing_db_06[
+        assert resp_ccv_0['calibration_constant']['id'] == self.exist_db_06[
             'calibration_constant_id']
 
         # Physical Device info
         assert resp_ccv_0['physical_detector_unit']['id'] == \
-               self.existing_db_06['physical_detector_unit_id']
+               self.exist_db_06['physical_detector_unit_id']
 
         #
         # Calibration Constant Version info (position 1)
         resp_ccv_1 = response_data[1]
 
-        assert resp_ccv_1['name'] == self.existing_db_05['name']
-        assert resp_ccv_1['flg_good_quality'] == self.existing_db_05[
+        assert resp_ccv_1['name'] == self.exist_db_05['name']
+        assert resp_ccv_1['flg_good_quality'] == self.exist_db_05[
             'flg_good_quality']
 
-        assert resp_ccv_1['begin_validity_at'] == self.existing_db_05[
+        assert resp_ccv_1['begin_validity_at'] == self.exist_db_05[
             'begin_validity_at']
-        assert resp_ccv_1['end_validity_at'] == self.existing_db_05[
+        assert resp_ccv_1['end_validity_at'] == self.exist_db_05[
             'end_validity_at']
-        assert resp_ccv_1['begin_at'] == self.existing_db_05['begin_at']
+        assert resp_ccv_1['begin_at'] == self.exist_db_05['begin_at']
 
-        assert resp_ccv_1['flg_deployed'] == self.existing_db_05['flg_deployed']
-        assert resp_ccv_1['raw_data_location'] == self.existing_db_05[
+        assert resp_ccv_1['flg_deployed'] == self.exist_db_05['flg_deployed']
+        assert resp_ccv_1['raw_data_location'] == self.exist_db_05[
             'raw_data_location']
-        assert resp_ccv_1['file_name'] == self.existing_db_05['file_name']
-        assert resp_ccv_1['path_to_file'] == self.existing_db_05['path_to_file']
-        assert resp_ccv_1['description'] == self.existing_db_05['description']
+        assert resp_ccv_1['file_name'] == self.exist_db_05['file_name']
+        assert resp_ccv_1['path_to_file'] == self.exist_db_05['path_to_file']
+        assert resp_ccv_1['description'] == self.exist_db_05['description']
         # Special cases...
-        assert resp_ccv_1['data_set_name'] == self.existing_db_05[
+        assert resp_ccv_1['data_set_name'] == self.exist_db_05[
             'data_set_name']
-        assert resp_ccv_1['start_idx'] == self.existing_db_05['start_idx']
-        assert resp_ccv_1['end_idx'] == self.existing_db_05['end_idx']
+        assert resp_ccv_1['start_idx'] == self.exist_db_05['start_idx']
+        assert resp_ccv_1['end_idx'] == self.exist_db_05['end_idx']
 
         # Calibration Constant info
-        assert resp_ccv_1['calibration_constant']['id'] == self.existing_db_05[
+        assert resp_ccv_1['calibration_constant']['id'] == self.exist_db_05[
             'calibration_constant_id']
 
         # Physical Device info
         assert resp_ccv_1['physical_detector_unit']['id'] == \
-               self.existing_db_05['physical_detector_unit_id']
+               self.exist_db_05['physical_detector_unit_id']
 
     def test_retrieve_ccv_no_data_found(self):
         calibration_hash_01 = CalibrationTestHash(None).valid_search_01
@@ -389,14 +386,15 @@ class CalibrationClientTest(ModuleBase, unittest.TestCase):
             'detector_condition': det_cond_h_exp
         }
 
-        resp = self.cal_client.retrieve_calibration_constant_version(retrieve_h)
+        resp = self.cal_client.retrieve_calibration_constant_version(
+            retrieve_h)
 
         # Logging information
         logging.error('calibration_hash_01: {0}'.format(calibration_hash_01))
         logging.error('retrieve_h: {0}'.format(retrieve_h))
         logging.error('resp: {0}'.format(resp))
 
-        assert resp['success'] == False
+        assert resp['success'] is False
         assert resp['app_info'] == RESOURCE_NOT_FOUND
         assert resp['data'] == {}
 
@@ -508,7 +506,7 @@ class CalibrationClientTest(ModuleBase, unittest.TestCase):
         logging.error('update_h: {0}'.format(update_h))
         logging.error('resp: {0}'.format(resp))
 
-        assert resp['success'] == True
+        assert resp['success'] is True
         assert resp['app_info'] == {}
 
         success_info_msg = 'calibration_constant_version updated successfully'
@@ -536,7 +534,7 @@ class CalibrationClientTest(ModuleBase, unittest.TestCase):
             update_back_h
         )
 
-        assert resp['success'] == True
+        assert resp['success'] is True
         assert resp['app_info'] == {}
 
         success_info_msg = 'calibration_constant_version updated successfully'
@@ -559,7 +557,7 @@ class CalibrationClientTest(ModuleBase, unittest.TestCase):
         logging.error('update_h_failed: {0}'.format(update_h_failed))
         logging.error('resp_failed: {0}'.format(resp_failed))
 
-        assert resp_failed['success'] == False
+        assert resp_failed['success'] is False
         assert resp_failed['app_info'] == 'Resource not found!'
 
         success_info_msg = 'calibration_constant_version not found!'
