@@ -1,8 +1,9 @@
 """CalibrationConstantTest class"""
 
-import pytest
 import unittest
 
+import pytest
+
 from .module_base import ModuleBase
 from ..common.config_test import CALIBRATION_CONSTANT, RESOURCE_NOT_FOUND
 from ..common.generators import generate_unique_name
@@ -97,7 +98,8 @@ class CalibrationConstantTest(ModuleBase, unittest.TestCase):
             res_uk_error = CalibrationConstant.get_by_uk(
                 self.cal_client, calibration_id, detector_type_id, condition_id
             )
-            self.assert_find_error(MODULE_NAME, res_uk_error, RESOURCE_NOT_FOUND)
+            self.assert_find_error(MODULE_NAME, res_uk_error,
+                                   RESOURCE_NOT_FOUND)
 
             # Put entry information (update some fields should succeed)
             cc_01.name = self.cc_01_upd['name']
@@ -119,7 +121,8 @@ class CalibrationConstantTest(ModuleBase, unittest.TestCase):
             cc_01.description = self.cc_01_upd['description']
             result7 = cc_01.update()
 
-            expect_app_info = {'name': ['is too long (maximum is 255 characters)']}
+            expect_app_info = {
+                'name': ['is too long (maximum is 255 characters)']}
             self.assert_update_error(MODULE_NAME, result7, expect_app_info)
 
         finally:
