@@ -1,14 +1,15 @@
 """CalibrationConstantVersionTest class"""
 
-from dateutil.parser import parse as parse_dt
-import pytest
 import unittest
 
+import pytest
+from dateutil.parser import parse as parse_dt
+
 from .module_base import ModuleBase
+from ..common import generators
 from ..common.config_test import (
     CALIBRATION_CONSTANT_VERSION, PHYSICAL_DETECTOR_UNIT, RESOURCE_NOT_FOUND
 )
-from ..common import generators
 from ...modules.calibration_constant_version import CalibrationConstantVersion
 
 MODULE_NAME = CALIBRATION_CONSTANT_VERSION
@@ -162,11 +163,11 @@ class CalibrationConstantVersionTest(ModuleBase, unittest.TestCase):
         result1 = ccv_01.create()
         self.assert_create_success(MODULE_NAME, result1, self.ccv_01)
 
-        calibration_constant_version = result1['data']
-        ccv_id = calibration_constant_version['id']
-        ccv_name = calibration_constant_version['name']
-        ccv_cc_id = calibration_constant_version['calibration_constant']['id']
-        ccv_pd_id = calibration_constant_version['physical_detector_unit']['id']
+        calibration_constant_vers = result1['data']
+        ccv_id = calibration_constant_vers['id']
+        ccv_name = calibration_constant_vers['name']
+        ccv_cc_id = calibration_constant_vers['calibration_constant']['id']
+        ccv_pd_id = calibration_constant_vers['physical_detector_unit']['id']
 
         #
         # Create duplicated entry (should throw an error)
@@ -198,9 +199,12 @@ class CalibrationConstantVersionTest(ModuleBase, unittest.TestCase):
 
         #
         # Get entry by UK (should succeed)
-        # (calibration_constant_id, physical_detector_unit_id, event_at, snapshot_at)
+        # (calibration_constant_id,
+        #  physical_detector_unit_id,
+        #  event_at,
+        #  snapshot_at)
         #
-        ccv_event_at = calibration_constant_version['begin_at']
+        ccv_event_at = calibration_constant_vers['begin_at']
         ccv_snapshot_at = ''  # '' == Now()
 
         result_uk = CalibrationConstantVersion.get_by_uk(self.cal_client,
@@ -212,7 +216,10 @@ class CalibrationConstantVersionTest(ModuleBase, unittest.TestCase):
 
         #
         # Get entry by UK (should throw an error)
-        # (calibration_constant_id, physical_detector_unit_id, event_at, snapshot_at)
+        # (calibration_constant_id,
+        #  physical_detector_unit_id,
+        #  event_at,
+        #  snapshot_at)
         #
         calibration_constant_id = -666
         physical_detector_unit_id = -666
@@ -312,7 +319,8 @@ class CalibrationConstantVersionTest(ModuleBase, unittest.TestCase):
         snapshot_at = None
 
         result1 = CalibrationConstantVersion.get_closest_by_time(
-            self.cal_client, calibration_constant_ids, physical_detector_unit_id,
+            self.cal_client, calibration_constant_ids,
+            physical_detector_unit_id,
             event_at, snapshot_at)
 
         # result1 ==>
@@ -363,7 +371,8 @@ class CalibrationConstantVersionTest(ModuleBase, unittest.TestCase):
         snapshot_at = None
 
         result1 = CalibrationConstantVersion.get_closest_by_time(
-            self.cal_client, calibration_constant_ids, physical_detector_unit_id,
+            self.cal_client, calibration_constant_ids,
+            physical_detector_unit_id,
             event_at, snapshot_at)
 
         # result1 ==>
@@ -414,7 +423,8 @@ class CalibrationConstantVersionTest(ModuleBase, unittest.TestCase):
         snapshot_at = None
 
         result1 = CalibrationConstantVersion.get_all_versions(
-            self.cal_client, calibration_constant_ids, physical_detector_unit_id,
+            self.cal_client, calibration_constant_ids,
+            physical_detector_unit_id,
             event_at, snapshot_at)
 
         assert [(d['id'], d['name']) for d in result1['data']] == [
@@ -434,7 +444,8 @@ class CalibrationConstantVersionTest(ModuleBase, unittest.TestCase):
         snapshot_at = None
 
         result1 = CalibrationConstantVersion.get_all_versions(
-            self.cal_client, calibration_constant_ids, physical_detector_unit_id,
+            self.cal_client, calibration_constant_ids,
+            physical_detector_unit_id,
             event_at, snapshot_at)
 
         assert [(d['id'], d['name']) for d in result1['data']] == [
